import express from "express";
import { authorizeRoles, isAuthenticatedUser } from "../../middlewares/auth.js";
import {
  createOrder,
  getCancelledOrdersAdmin,
  getDeliveredOrdersAdmin,
  getDispatchedOrdersAdmin,
  getPlacedNewOrderAdmin,
  getPlacedOrder,
  getPlacedOrderById,
  getProcessingOrdersAdmin,
  updateOrderStatusById,
} from "./pdOrderController.js";

const router = express.Router();

router
  .route("/order-place")
  .post(
    isAuthenticatedUser,
    authorizeRoles("principal-Distributor"),
    createOrder
  );
router
  .route("/get-placed-order-pd")
  .get(
    isAuthenticatedUser,
    authorizeRoles("principal-Distributor"),
    getPlacedOrder
  );
router
  .route("/get-single-placed-order-pd/:id")
  .get(isAuthenticatedUser, getPlacedOrderById);
router
  .route("/get-new-order-admin")
  .get(isAuthenticatedUser, authorizeRoles("admin"), getPlacedNewOrderAdmin);
router
  .route("/get-dispatched-order-admin")
  .get(isAuthenticatedUser, authorizeRoles("admin"), getDispatchedOrdersAdmin);
router
  .route("/get-cancelled-order-admin")
  .get(isAuthenticatedUser, authorizeRoles("admin"), getCancelledOrdersAdmin);
router
  .route("/get-processing-order-admin")
  .get(isAuthenticatedUser, authorizeRoles("admin"), getProcessingOrdersAdmin);
router
  .route("/get-delivered-order-admin")
  .get(isAuthenticatedUser, authorizeRoles("admin"), getDeliveredOrdersAdmin);
router
  .route("/change/status/:id")
  .patch(isAuthenticatedUser, authorizeRoles("admin"), updateOrderStatusById);

export default router;
